==> lambdaelasticsearchkibana-1.94.0-sources.jar: software/amazon/awsconstructs/services/lambdaelasticsearchkibana/LambdaToElasticSearchAndKibana.java <==
package software.amazon.awsconstructs.services.lambdaelasticsearchkibana;

@javax.annotation.Generated(value = "jsii-pacmak/1.26.0 (build 7d76e02)", date = "2021-04-02T01:59:45.245Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdaelasticsearchkibana.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-elasticsearch-kibana.LambdaToElasticSearchAndKibana")
public class LambdaToElasticSearchAndKibana extends software.amazon.awscdk.core.Construct {

    protected LambdaToElasticSearchAndKibana(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToElasticSearchAndKibana(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToElasticSearchAndKibana(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibanaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticsearch.CfnDomain getElasticsearchDomain() {
        return software.amazon.jsii.Kernel.get(this, "elasticsearchDomain", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.elasticsearch.CfnDomain.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.Role getElasticsearchRole() {
        return software.amazon.jsii.Kernel.get(this, "elasticsearchRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.CfnIdentityPool getIdentityPool() {
        return software.amazon.jsii.Kernel.get(this, "identityPool", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.CfnIdentityPool.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPool getUserPool() {
        return software.amazon.jsii.Kernel.get(this, "userPool", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.UserPool.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPoolClient getUserPoolClient() {
        return software.amazon.jsii.Kernel.get(this, "userPoolClient", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.UserPoolClient.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibana}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibana> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibanaProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibanaProps.Builder();
        }

        /**
         * Cognito & ES Domain Name.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param domainName Cognito & ES Domain Name. This parameter is required.
         */
        public Builder domainName(final java.lang.String domainName) {
            this.props.domainName(domainName);
            return this;
        }

        /**
         * Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param cognitoDomainName Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain. This parameter is required.
         */
        public Builder cognitoDomainName(final java.lang.String cognitoDomainName) {
            this.props.cognitoDomainName(cognitoDomainName);
            return this;
        }

        /**
         * Whether to create recommended CloudWatch alarms.
         * <p>
         * Default: - Alarms are created
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param domainEndpointEnvironmentVariableName Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function. This parameter is required.
         */
        public Builder domainEndpointEnvironmentVariableName(final java.lang.String domainEndpointEnvironmentVariableName) {
            this.props.domainEndpointEnvironmentVariableName(domainEndpointEnvironmentVariableName);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the Elasticsearch Service.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param esDomainProps Optional user provided props to override the default props for the Elasticsearch Service. This parameter is required.
         */
        public Builder esDomainProps(final software.amazon.awscdk.services.elasticsearch.CfnDomainProps esDomainProps) {
            this.props.esDomainProps(esDomainProps);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibana}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibana build() {
            return new software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibana(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> lambdaelasticsearchkibana-1.123.0-sources.jar: software/amazon/awsconstructs/services/lambdaelasticsearchkibana/LambdaToElasticSearchAndKibana.java <==
package software.amazon.awsconstructs.services.lambdaelasticsearchkibana;

@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-21T01:42:13.070Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdaelasticsearchkibana.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-elasticsearch-kibana.LambdaToElasticSearchAndKibana")
public class LambdaToElasticSearchAndKibana extends software.amazon.awscdk.core.Construct {

    protected LambdaToElasticSearchAndKibana(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToElasticSearchAndKibana(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToElasticSearchAndKibana(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibanaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticsearch.CfnDomain getElasticsearchDomain() {
        return software.amazon.jsii.Kernel.get(this, "elasticsearchDomain", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.elasticsearch.CfnDomain.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.Role getElasticsearchRole() {
        return software.amazon.jsii.Kernel.get(this, "elasticsearchRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.CfnIdentityPool getIdentityPool() {
        return software.amazon.jsii.Kernel.get(this, "identityPool", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.CfnIdentityPool.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPool getUserPool() {
        return software.amazon.jsii.Kernel.get(this, "userPool", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.UserPool.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPoolClient getUserPoolClient() {
        return software.amazon.jsii.Kernel.get(this, "userPoolClient", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.UserPoolClient.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibana}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibana> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibanaProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibanaProps.Builder();
        }

        /**
         * Cognito & ES Domain Name.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param domainName Cognito & ES Domain Name. This parameter is required.
         */
        public Builder domainName(final java.lang.String domainName) {
            this.props.domainName(domainName);
            return this;
        }

        /**
         * Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param cognitoDomainName Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain. This parameter is required.
         */
        public Builder cognitoDomainName(final java.lang.String cognitoDomainName) {
            this.props.cognitoDomainName(cognitoDomainName);
            return this;
        }

        /**
         * Whether to create recommended CloudWatch alarms.
         * <p>
         * Default: - Alarms are created
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param domainEndpointEnvironmentVariableName Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function. This parameter is required.
         */
        public Builder domainEndpointEnvironmentVariableName(final java.lang.String domainEndpointEnvironmentVariableName) {
            this.props.domainEndpointEnvironmentVariableName(domainEndpointEnvironmentVariableName);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the Elasticsearch Service.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param esDomainProps Optional user provided props to override the default props for the Elasticsearch Service. This parameter is required.
         */
        public Builder esDomainProps(final software.amazon.awscdk.services.elasticsearch.CfnDomainProps esDomainProps) {
            this.props.esDomainProps(esDomainProps);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibana}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibana build() {
            return new software.amazon.awsconstructs.services.lambdaelasticsearchkibana.LambdaToElasticSearchAndKibana(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
